LabelBasedInitializer
=====================

.. currentmodule:: pykeen.nn.init

.. autoclass:: LabelBasedInitializer
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~LabelBasedInitializer.from_triples_factory

   .. rubric:: Methods Documentation

   .. automethod:: from_triples_factory
